<p align="center">
  <h1 align="center">instabotClub</h1>
  <br />
  <p align="center">Looking for Instagram automation? I'm proud to present you a <b>InstabotClub Instagram Bot.</b>. This bot will allow you to grow your following and engagement by liking, following, commenting and sending PM automatically with your Android phone/tablet/emulator. <b>No root required.</b> <p>
</p>


## Cool! What can I do with this bot? 

- Works without rooting
- Works with both emulators and physical devices
- Can be used stand-alone (without the use of a computer)
- Includes realistic random human-like delays and actions
- Can watch stories while interacting
- Comment post with emojis and [spintax logic]
- Send PM
- Type like a human (letter by letter by faking using suggestions. For example you won't type `H - e - l - l - o` letter by letter but something like `H - He - Hello`)
- Browse carousels and watch their contents
- Watch videos for a specific amount of time
- Scheduler
- Getting tasty telegram reports
- Supports multiple actions in one session
- Lots of customizable limits to keep your account safe from soft bans
- Available interactions
    - interact with a user's followers or following
    - interact with a top or recent hashtag's post likers
    - interact with a top or recent hashtag post
    - interact with a top or recent place's post likers
    - interact with a top or recent place post
    - interact with user's post likers
    - interact with a single blogger
    - interact with your feed
    - interact with users from a list (*.txt)
    - interact with posts from links inside a list (*.txt)
    - unfollow any followers
    - unfollow any followers, followed by bot
    - unfollow any followers, followed by bot, who don't follow you back
    - unfollow from a list (*.txt)
    - scrape mode for collecting usernames instead of interacting with them (you will find more information about that in the doc)

- Lots of available filters to customize who you interact with
    - you can blacklist people to avoid interacting with them
    - you can whitelist people to not remove them when you unfollow people
    - biography main characters and language
    - profile name main characters
    - private / public / business / non business account
    - number of posts / followers / following
    ... and more!
<br />

You can BUY this very cool Instagram Tool here: https://www.instabot.club.
